PAWpySeed: band Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
band Struct Reference

`#include <utils.h>`

Collaboration diagram for band:
[legend]

## Public Attributes
int | n
| band number More...
int | num_waves
| number of plane waves More...
double | occ
| occupancy of the band More...
double | N
double | energy
| energy of the band More...
float complex * | Cs
| plane wave coefficients (normalized to 1) More...
double complex * | CRs
| wavefunction in real space More...
projection_t * | projections
| length==number of sites in structure More...
projection_t * | up_projections
| length==number of sites in structure More...
projection_t * | down_projections
| length==number of sites in structure More...
projection_t * | wave_projections
| used for offsite compensation terms More...

## Detailed Description

Stores the data for a single band, or Kohn Sham single particle state, for a structure

## Member Data Documentation

double complex* band::CRs

wavefunction in real space

float complex* band::Cs

plane wave coefficients (normalized to 1)

projection_t* band::down_projections

length==number of sites in structure

double band::energy

energy of the band

int band::n

band number

double band::N

int band::num_waves

number of plane waves

double band::occ

occupancy of the band

projection_t* band::projections

length==number of sites in structure

projection_t* band::up_projections

length==number of sites in structure

projection_t* band::wave_projections

used for offsite compensation terms

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/utils.h